==> kernel-1.1.4.2-sources.jar: voxeet/com/sdk/json/EventNames.java <==
package voxeet.com.sdk.json;

/**
 * Created by Thomas on 20/10/2015.
 */
public class EventNames {

    // SdkConferenceService Service
    public static final String OFFER_CREATED = "OfferCreated";
    public static final String PARTICIPANT_UPDATED = "ParticipantUpdated";
    public static final String JOIN_CONFERENCE = "JoinConference";
    public static final String DEVICE_TYPE = "DeviceType";
    public static final String GRAND_TYPE = "GrandType";
    public static final String OWN_CONFERENCE_CREATED = "OwnConferenceCreatedEvent";
    public static final String QUALITY_UPDATED = "QualityUpdated";
    public static final String CONFERENCE_DESTROYED = "ConferenceDestroyedPush";
    public static final String BROADCAST_EVENT = "BroadcastEvent";
    public static final String CONFERENCE_MESSAGE_RECEIVED = "ConferenceMessageReceived";
    public static final String OWN_PROFILE_UPDATED = "OwnProfileUpdatedEvent";
    public static final String CONFERENCE_UPDATED = "ConferenceStatusUpdated";

    // User Service
    public static final String LOGIN = "Login";
    public static final String SOCIAL_LOGIN = "SocialLogin";
    public static final String RESET_PASSWORD = "ResetPassword";
    public static final String SIGN_UP = "SignUp";
    public static final String EMAIL = "Email";
    public static final String UPDATE_PASSWORD = "UpdatePassword";
    public static final String UPDATE_PROFILE = "UpdateProfile";
    public static final String UPDATE_PRESENCE = "UpdatePresence";
    public static final String OWN_PROFILE = "OwnProfileUpdated";
    public static final String USER_LOG_OUT = "UserLogoutEvent";
    public static final String UNIQUE_URL = "UniqueUrl";

    // Contact Service
    public static final String OWN_EXTERNAL_INVITATION = "OwnExternalInvitationsSentEvent";
    public static final String CONTACT_PROFILE_UPDATED = "ProfileUpdatedEvent";
    public static final String OWN_CONTACT_REMOVED = "OwnContactRemovedEvent";
    public static final String GET_CONTACT = "GetContactEvent";
    public static final String CONTACT_ADDED = "ContactsAddedEvent";

    // Meetings
    public static final String MEETING_ADDED_OR_UPDATED = "MeetingAddedOrUpdatedEvent";
    public static final String MEETING_DELETED = "MeetingDeletedEvent";
    public static final String MEETING_EVENT_ADDED_OR_UPDATED = "MeetingEventAddedOrUpdatedEvent";
    public static final String BADGE_UPDATE_EVENT = "BadgeCounterUpdatedEvent";
    public static final String MEET_ACTIVITY_DELETED = "MeetActivityDeletedEvent";
    public static final String MEET_ACTIVITY_ADDED = "MeetActivityAddedEvent";
    public static final String MEET_ACTIVITY_UPDATED = "MeetActivityUpdatedEvent";
    public static final String MEET_READ_TIMESTAMP_UPDATED = "MeetingReadTimestampUpdatedEvent";
    public static final String INVITATION_RECEIVED = "InvitationReceivedEvent";
    public static final String TYPING_DETECTION = "TypingDetection";

    public static final String ERROR_EVENT = "ErrorEvent";
    public static final String STATE_GENERATOR = "StateGeneratorEvent";

    //Files
    public static final String FILE_DELETED = "FileDeletedEvent";
    public static final String FILE_ADDED = "FileSharedEvent";
    public static final String FILE_CONVERTED = "FileConvertedEvent";

    public static final String PLAY_EMO_SPHERE = "PlayEmosphere";

    //Conferences
    public static final String RECORDING_STATUS_UPDATE = "RecordingStatusUpdated";
    public static final String WHISPER_INVITATION_RECEIVED = "WhisperInvitationReceivedEvent";
    public static final String WHISPER_INVITATION_DECLINED = "WhisperDeclinedEvent";
    public static final String WHISPER_INVITATION_ACCEPTED = "WhisperAcceptedEvent";
    public static final String WHISPER_LEFT = "WhisperLeftEvent";
    public static final String OWN_USER_INVITED = "OwnUserInvitedEvent";
    public static final String PARTICIPANT_ADDED = "ParticipantAdded";
    public static final String PARTICIPANT_SWITCH = "ParticipantSwitched";
    public static final String OWN_USER_SWITCH = "OwnParticipantSwitched";
    public static final String CONFERENCE_ENDED = "ConferenceEndedEvent";
    public static final String PEER_CONNECTION_UPDATED = "PeerConnectionStatusUpdatedEvent";
    public static final String RENEGOCIATION_ENDED = "RenegociationEnded";

    //File Presentation
    public static final String FILE_PRESENTATION_START = "FilePresentationStart";
    public static final String FILE_PRESENTATION_CHANGE = "FilePresentationChange";
    public static final String FILE_PRESENTATION_STOP = "FilePresentationStop";
    public static final String FILE_PRESENTATION_STARTED = "FilePresentationStarted";//v2
    public static final String FILE_PRESENTATION_STOPPED = "FilePresentationStopped";//v2
    public static final String FILE_PRESENTATION_UPDATED = "FilePresentationUpdated";//v2
    public static final String USER_INVITED = "UserInvited";

    //Video stuff related
    public static final String STOP_VIDEO = "StopVideoResponse";
    public static final String START_VIDEO = "StartVideoResponse";

    //ScreenShare
    public static final String START_SCREENSHARE = "StartScreenSharingResponse";
    public static final String STOP_SCREENSHARE = "StopScreenSharingResponse";

    //Sdk conference
    public static final String SDK_CONFERENCE_CREATED = "SdkConferenceCreated";
    public static final String SDK_CONFERENCE_ENDED = "SdkConferenceEnded";
    public static final String CONFERENCE_STATS = "ConferenceStats";
}

==> kernel-1.1.8.29-sources.jar: voxeet/com/sdk/json/EventNames.java <==
package voxeet.com.sdk.json;

/**
 * Created by Thomas on 20/10/2015.
 */
public class EventNames {

    // SdkConferenceService Service
    public static final String OFFER_CREATED = "OfferCreated";
    public static final String PARTICIPANT_UPDATED = "ParticipantUpdated";
    public static final String JOIN_CONFERENCE = "JoinConference";
    public static final String DEVICE_TYPE = "DeviceType";
    public static final String GRAND_TYPE = "GrandType";
    public static final String OWN_CONFERENCE_CREATED = "OwnConferenceCreatedEvent";
    public static final String QUALITY_UPDATED = "QualityUpdated";
    public static final String CONFERENCE_DESTROYED = "ConferenceDestroyedPush";
    public static final String BROADCAST_EVENT = "BroadcastEvent";
    public static final String CONFERENCE_MESSAGE_RECEIVED = "ConferenceMessageReceived";
    public static final String OWN_PROFILE_UPDATED = "OwnProfileUpdatedEvent";
    public static final String CONFERENCE_UPDATED = "ConferenceStatusUpdated";

    // User Service
    public static final String LOGIN = "Login";
    public static final String SOCIAL_LOGIN = "SocialLogin";
    public static final String RESET_PASSWORD = "ResetPassword";
    public static final String SIGN_UP = "SignUp";
    public static final String EMAIL = "Email";
    public static final String UPDATE_PASSWORD = "UpdatePassword";
    public static final String UPDATE_PROFILE = "UpdateProfile";
    public static final String UPDATE_PRESENCE = "UpdatePresence";
    public static final String OWN_PROFILE = "OwnProfileUpdated";
    public static final String USER_LOG_OUT = "UserLogoutEvent";
    public static final String UNIQUE_URL = "UniqueUrl";

    // Contact Service
    public static final String OWN_EXTERNAL_INVITATION = "OwnExternalInvitationsSentEvent";
    public static final String CONTACT_PROFILE_UPDATED = "ProfileUpdatedEvent";
    public static final String OWN_CONTACT_REMOVED = "OwnContactRemovedEvent";
    public static final String GET_CONTACT = "GetContactEvent";
    public static final String CONTACT_ADDED = "ContactsAddedEvent";

    // Meetings
    public static final String MEETING_ADDED_OR_UPDATED = "MeetingAddedOrUpdatedEvent";
    public static final String MEETING_DELETED = "MeetingDeletedEvent";
    public static final String MEETING_EVENT_ADDED_OR_UPDATED = "MeetingEventAddedOrUpdatedEvent";
    public static final String BADGE_UPDATE_EVENT = "BadgeCounterUpdatedEvent";
    public static final String MEET_ACTIVITY_DELETED = "MeetActivityDeletedEvent";
    public static final String MEET_ACTIVITY_ADDED = "MeetActivityAddedEvent";
    public static final String MEET_ACTIVITY_UPDATED = "MeetActivityUpdatedEvent";
    public static final String MEET_READ_TIMESTAMP_UPDATED = "MeetingReadTimestampUpdatedEvent";
    public static final String INVITATION_RECEIVED = "InvitationReceivedEvent";
    public static final String TYPING_DETECTION = "TypingDetection";

    public static final String ERROR_EVENT = "ErrorEvent";
    public static final String STATE_GENERATOR = "StateGeneratorEvent";

    //Files
    public static final String FILE_DELETED = "FileDeletedEvent";
    public static final String FILE_ADDED = "FileSharedEvent";
    public static final String FILE_CONVERTED = "FileConvertedEvent";

    public static final String PLAY_EMO_SPHERE = "PlayEmosphere";

    //Conferences
    public static final String RECORDING_STATUS_UPDATE = "RecordingStatusUpdated";
    public static final String WHISPER_INVITATION_RECEIVED = "WhisperInvitationReceivedEvent";
    public static final String WHISPER_INVITATION_DECLINED = "WhisperDeclinedEvent";
    public static final String WHISPER_INVITATION_ACCEPTED = "WhisperAcceptedEvent";
    public static final String WHISPER_LEFT = "WhisperLeftEvent";
    public static final String OWN_USER_INVITED = "OwnUserInvitedEvent";
    public static final String PARTICIPANT_ADDED = "ParticipantAdded";
    public static final String PARTICIPANT_SWITCH = "ParticipantSwitched";
    public static final String OWN_USER_SWITCH = "OwnParticipantSwitched";
    public static final String CONFERENCE_ENDED = "ConferenceEndedEvent";
    public static final String PEER_CONNECTION_UPDATED = "PeerConnectionStatusUpdatedEvent";
    public static final String RENEGOCIATION_ENDED = "RenegociationEnded";

    //File Presentation
    public static final String FILE_PRESENTATION_START = "FilePresentationStart";
    public static final String FILE_PRESENTATION_CHANGE = "FilePresentationChange";
    public static final String FILE_PRESENTATION_STOP = "FilePresentationStop";
    public static final String FILE_PRESENTATION_STARTED = "FilePresentationStarted";//v2
    public static final String FILE_PRESENTATION_STOPPED = "FilePresentationStopped";//v2
    public static final String FILE_PRESENTATION_UPDATED = "FilePresentationUpdated";//v2
    public static final String USER_INVITED = "UserInvited";

    //Video Presentation
    public static final String VIDEO_PRESENTATION_STARTED = "VideoPresentationStarted";
    public static final String VIDEO_PRESENTATION_STOPPED = "VideoPresentationStopped";
    public static final String VIDEO_PRESENTATION_PLAY = "VideoPresentationPlay";
    public static final String VIDEO_PRESENTATION_SEEK = "VideoPresentationSeek";
    public static final String VIDEO_PRESENTATION_PAUSED = "VideoPresentationPaused";

    //Video stuff related
    public static final String STOP_VIDEO = "StopVideoResponse";
    public static final String START_VIDEO = "StartVideoResponse";

    //ScreenShare
    public static final String START_SCREENSHARE = "StartScreenSharingResponse";
    public static final String STOP_SCREENSHARE = "StopScreenSharingResponse";

    //Sdk conference
    public static final String SDK_CONFERENCE_CREATED = "SdkConferenceCreated";
    public static final String SDK_CONFERENCE_ENDED = "SdkConferenceEnded";
    public static final String CONFERENCE_STATS = "ConferenceStats";
}
